@@ -4,6 +4,9 @@
 from typing import Optional, Union, List, Dict, Any
 import os
 
+# Local
+from .category import Category
+
 # ---------------------------------------------------------------------------------------------------------------------------------------- #
 
 
@@ -15,9 +18,10 @@ class AmazonBuddy:
     # -------------------------------------------------------- Public methods -------------------------------------------------------- #
 
     @classmethod
-    def search_asins(
+    def search_products(
         cls,
         search_term: str,
+        category: Category = Category.ALL_DEPARTMENTS,
         ignored_title_strs: List[str] = [],
         ignored_asins: List[str] = [],
         min_price: float = 50.0,
@@ -32,6 +36,7 @@ class AmazonBuddy:
             random_ua=random_ua,
             extra_params={
                 '-k': '\'' + search_term + '\'',
+                '-c': category.value,
                 '-n': max_results,
                 '--min-rating': min_rating,
                 '--sort': sort
@@ -45,17 +50,19 @@ class AmazonBuddy:
 
         for product in products:
             try:
+                from kcu import strings
+
                 product['price'] = float(product['price'].replace(',', ''))
-                product['asin'] = strings.string_between(product['url'].replace('%2F', '/'), '/dp/', '/')
+                product['asin'] = strings.between(product['url'].replace('%2F', '/'), '/dp/', '/')
 
                 if (
                     product['price'] < min_price
                     or
                     product['reviews'] < min_reviews
                     or
-                    self.__contains(product['asin'], ignored_asins)
+                    cls.__contains(product['asin'], ignored_asins)
                     or
-                    self.__contains_in(product['title'], ignored_title_strs)
+                    cls.__contains_in(product['title'], ignored_title_strs)
                 ):
                     continue
 
@@ -147,6 +154,15 @@ class AmazonBuddy:
         cmd = 'amazon-buddy' + ' ' + feature
 
         for k, v in params.items():
+            if k == '--random-ua':
+                k = '--ua'
+
+                from fake_useragent import FakeUserAgent
+
+                v = '\'' + FakeUserAgent().random.replace('\'', '\\\'') + '\''
+            if isinstance(v, bool):
+                v = str(v).lower()
+
             cmd += ' ' + k + ' ' + str(v)
         
         return cmd
